==> claromentis-framework-9.6.6-26891208.zip: web/intranet/search/classes/QueryBuilder.php <==
<?php
namespace Claromentis\Search;

$GLOBALS["__65da1b1ec2d6653e8a0" . "ab7848e536215"] = (@$GLOBALS["__65da1b1ec2d6653e8a0a" . "b7848e536215"] ?: array()) + array("_8f7d73e71f75959" . "5e26c94678ca29d8" . "5" => base64_decode("Y2ZnX3NlYXJ" . "jaF9lc192ZX" . "JzaW9u"));
use Claromentis\Search\QueryBuilders\AbstractQueryBuilder;
use Claromentis\Search\QueryBuilders\QueryBuilderV7;
use Claromentis\Search\QueryBuilders\QueryBuilderV1;




class QueryBuilder implements QueryBuilderInterface
{
    
    
    protected $inner;
    public function __construct(string $_c80a67ccfaf6579232efc354d30eb275 = null)
    {
        $_c80a67ccfaf6579232efc354d30eb275 = $_c80a67ccfaf6579232efc354d30eb275 ?? \Claromentis\Core\Services::I()->config[$GLOBALS["__65da1b1ec2d6653e" . "8a0ab7848e536215"]["_8f7d73e71f759595e26c94678ca" . "29d85"]];
        if ($_c80a67ccfaf6579232efc354d30eb275 === SearchApplication::ES_7) {
            $this->inner = new QueryBuilderV7();
        } else {
            $this->inner = new QueryBuilderV1();
        }
    }
    public function SetParameters(Parameters $_7513206ad0d1ac947614f69369d81e78)
    {
        return $this->inner->SetParameters($_7513206ad0d1ac947614f69369d81e78);
    }
    
    
    
    
    
    public function GetOptions()
    {
        return $this->inner->GetOptions();
    }
    
    
    
    
    
    public function GetQuery()
    {
        return $this->inner->GetQuery();
    }
    public function GetInner() : AdvancedQueryBuilderInterface
    {
        return $this->inner;
    }
}

==> claromentis-framework-10.3.3-59629072.zip: web/intranet/search/classes/QueryBuilder.php <==
<?php
namespace Claromentis\Search;

$GLOBALS["__65da1b1ec2d6653e8a0ab784" . "8e536215"] = (@$GLOBALS["__65da1b1ec2d6653e8a0ab784" . "8e536215"] ?: array()) + array("_8f7d73e7" . "1f759595e" . "26c94678c" . "a29d85" => base64_decode("Y2ZnX3NlYXJja" . "F9lc192ZXJzaW" . "9u"));
use Claromentis\Search\QueryBuilders\AbstractQueryBuilder;
use Claromentis\Search\QueryBuilders\QueryBuilderV7;
use Claromentis\Search\QueryBuilders\QueryBuilderV1;




class QueryBuilder implements QueryBuilderInterface
{
    
    
    protected $inner;
    public function __construct(string $_c80a67ccfaf6579232efc354d30eb275 = null)
    {
        $_c80a67ccfaf6579232efc354d30eb275 = $_c80a67ccfaf6579232efc354d30eb275 ?? \Claromentis\Core\Services::I()->config[$GLOBALS["__65da1b1e" . "c2d6653e8a" . "0ab7848e53" . "6215"]["_8f7d73e71f759595e26c94678ca29" . "d85"]];
        if ($_c80a67ccfaf6579232efc354d30eb275 === SearchApplication::ES_7) {
            $this->inner = new QueryBuilderV7();
        } else {
            $this->inner = new QueryBuilderV1();
        }
    }
    public function SetParameters(Parameters $_7513206ad0d1ac947614f69369d81e78)
    {
        return $this->inner->SetParameters($_7513206ad0d1ac947614f69369d81e78);
    }
    
    
    
    
    
    public function GetOptions()
    {
        return $this->inner->GetOptions();
    }
    
    
    
    
    
    public function GetQuery()
    {
        return $this->inner->GetQuery();
    }
    public function GetInner() : AdvancedQueryBuilderInterface
    {
        return $this->inner;
    }
}
